nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Aircr

Struct Aircr 

#[repr(transparent)]
pub struct Aircr(pub u32);
Application Interrupt and Reset Control Register.

Tuple Fields

0: u32

Implementations

Source

impl Aircr

pub const fn vectclractive(&self) -> bool

Reserved for Debug use. This bit reads as 0. When writing to the register you must write 0 to this bit, otherwise behavior is UNPREDICTABLE. This bit is not banked between Security states.

pub const fn set_vectclractive(&mut self, val: bool)

Reserved for Debug use. This bit reads as 0. When writing to the register you must write 0 to this bit, otherwise behavior is UNPREDICTABLE. This bit is not banked between Security states.

pub const fn sysresetreq(&self) -> Sysresetreq

System reset request. This bit allows software or a debugger to request a system reset. This bit is not banked between Security states. RW if SYSRESETREQS is 0. When SYSRESETREQS is set to 1, from Non-secure state this bit acts as RAZ/WI.

pub const fn set_sysresetreq(&mut self, val: Sysresetreq)

System reset request. This bit allows software or a debugger to request a system reset. This bit is not banked between Security states. RW if SYSRESETREQS is 0. When SYSRESETREQS is set to 1, from Non-secure state this bit acts as RAZ/WI.

pub const fn sysresetreqs(&self) -> Sysresetreqs

System reset request, Secure state only. The value of this bit defines whether the SYSRESETREQ bit is functional for Non-secure use. This bit is not banked between Security states. RW from Secure State and RAZ/WI from Non-secure state.

pub const fn set_sysresetreqs(&mut self, val: Sysresetreqs)

System reset request, Secure state only. The value of this bit defines whether the SYSRESETREQ bit is functional for Non-secure use. This bit is not banked between Security states. RW from Secure State and RAZ/WI from Non-secure state.

pub const fn prigroup(&self) -> u8

Interrupt priority grouping field. This field determines the split of group priority from subpriority. This bit is banked between Security states.

pub const fn set_prigroup(&mut self, val: u8)

Interrupt priority grouping field. This field determines the split of group priority from subpriority. This bit is banked between Security states.

pub const fn bfhfnmins(&self) -> Bfhfnmins

BusFault, HardFault, and NMI Non-secure enable. The value of this bit defines whether BusFault and NMI exceptions are Non-secure, and whether exceptions target the Non-secure HardFault exception. This bit is not banked between Security states. RW from Secure-state and RO from Non-secure state.

pub const fn set_bfhfnmins(&mut self, val: Bfhfnmins)

BusFault, HardFault, and NMI Non-secure enable. The value of this bit defines whether BusFault and NMI exceptions are Non-secure, and whether exceptions target the Non-secure HardFault exception. This bit is not banked between Security states. RW from Secure-state and RO from Non-secure state.

pub const fn pris(&self) -> Pris

Prioritize Secure exceptions. The value of this bit defines whether Secure exception priority boosting is enabled. This bit is not banked between Security states. RW from Secure state and RAZ/WI from Non-secure state.

pub const fn set_pris(&mut self, val: Pris)

Prioritize Secure exceptions. The value of this bit defines whether Secure exception priority boosting is enabled. This bit is not banked between Security states. RW from Secure state and RAZ/WI from Non-secure state.

pub const fn endianness(&self) -> Endianness

Data endianness bit. This bit is not banked between Security states.

pub const fn set_endianness(&mut self, val: Endianness)

Data endianness bit. This bit is not banked between Security states.

pub const fn vectkey(&self) -> u16

Register key: Reads as 0xFA05. On writes, write 0x5FA to VECTKEY, otherwise the write is ignored. This Field is not banked between Security states.

pub const fn set_vectkey(&mut self, val: u16)

Register key: Reads as 0xFA05. On writes, write 0x5FA to VECTKEY, otherwise the write is ignored. This Field is not banked between Security states.