#[repr(transparent)]pub struct Aircr(pub u32);Expand description
Application Interrupt and Reset Control Register.
Tuple Fields
0: u32Implementations
Sourceimpl Aircr
impl Aircr
Sourcepub const fn vectclractive(&self) -> bool
pub const fn vectclractive(&self) -> bool
Reserved for Debug use. This bit reads as 0. When writing to the register you must write 0 to this bit, otherwise behavior is UNPREDICTABLE. This bit is not banked between Security states.
Sourcepub const fn set_vectclractive(&mut self, val: bool)
pub const fn set_vectclractive(&mut self, val: bool)
Reserved for Debug use. This bit reads as 0. When writing to the register you must write 0 to this bit, otherwise behavior is UNPREDICTABLE. This bit is not banked between Security states.
Sourcepub const fn sysresetreq(&self) -> Sysresetreq
pub const fn sysresetreq(&self) -> Sysresetreq
System reset request. This bit allows software or a debugger to request a system reset. This bit is not banked between Security states. RW if SYSRESETREQS is 0. When SYSRESETREQS is set to 1, from Non-secure state this bit acts as RAZ/WI.
Sourcepub const fn set_sysresetreq(&mut self, val: Sysresetreq)
pub const fn set_sysresetreq(&mut self, val: Sysresetreq)
System reset request. This bit allows software or a debugger to request a system reset. This bit is not banked between Security states. RW if SYSRESETREQS is 0. When SYSRESETREQS is set to 1, from Non-secure state this bit acts as RAZ/WI.
Sourcepub const fn sysresetreqs(&self) -> Sysresetreqs
pub const fn sysresetreqs(&self) -> Sysresetreqs
System reset request, Secure state only. The value of this bit defines whether the SYSRESETREQ bit is functional for Non-secure use. This bit is not banked between Security states. RW from Secure State and RAZ/WI from Non-secure state.
Sourcepub const fn set_sysresetreqs(&mut self, val: Sysresetreqs)
pub const fn set_sysresetreqs(&mut self, val: Sysresetreqs)
System reset request, Secure state only. The value of this bit defines whether the SYSRESETREQ bit is functional for Non-secure use. This bit is not banked between Security states. RW from Secure State and RAZ/WI from Non-secure state.
Sourcepub const fn prigroup(&self) -> u8
pub const fn prigroup(&self) -> u8
Interrupt priority grouping field. This field determines the split of group priority from subpriority. This bit is banked between Security states.
Sourcepub const fn set_prigroup(&mut self, val: u8)
pub const fn set_prigroup(&mut self, val: u8)
Interrupt priority grouping field. This field determines the split of group priority from subpriority. This bit is banked between Security states.
Sourcepub const fn bfhfnmins(&self) -> Bfhfnmins
pub const fn bfhfnmins(&self) -> Bfhfnmins
BusFault, HardFault, and NMI Non-secure enable. The value of this bit defines whether BusFault and NMI exceptions are Non-secure, and whether exceptions target the Non-secure HardFault exception. This bit is not banked between Security states. RW from Secure-state and RO from Non-secure state.
Sourcepub const fn set_bfhfnmins(&mut self, val: Bfhfnmins)
pub const fn set_bfhfnmins(&mut self, val: Bfhfnmins)
BusFault, HardFault, and NMI Non-secure enable. The value of this bit defines whether BusFault and NMI exceptions are Non-secure, and whether exceptions target the Non-secure HardFault exception. This bit is not banked between Security states. RW from Secure-state and RO from Non-secure state.
Sourcepub const fn pris(&self) -> Pris
pub const fn pris(&self) -> Pris
Prioritize Secure exceptions. The value of this bit defines whether Secure exception priority boosting is enabled. This bit is not banked between Security states. RW from Secure state and RAZ/WI from Non-secure state.
Sourcepub const fn set_pris(&mut self, val: Pris)
pub const fn set_pris(&mut self, val: Pris)
Prioritize Secure exceptions. The value of this bit defines whether Secure exception priority boosting is enabled. This bit is not banked between Security states. RW from Secure state and RAZ/WI from Non-secure state.
Sourcepub const fn endianness(&self) -> Endianness
pub const fn endianness(&self) -> Endianness
Data endianness bit. This bit is not banked between Security states.
Sourcepub const fn set_endianness(&mut self, val: Endianness)
pub const fn set_endianness(&mut self, val: Endianness)
Data endianness bit. This bit is not banked between Security states.
Sourcepub const fn vectkey(&self) -> u16
pub const fn vectkey(&self) -> u16
Register key: Reads as 0xFA05. On writes, write 0x5FA to VECTKEY, otherwise the write is ignored. This Field is not banked between Security states.
Sourcepub const fn set_vectkey(&mut self, val: u16)
pub const fn set_vectkey(&mut self, val: u16)
Register key: Reads as 0xFA05. On writes, write 0x5FA to VECTKEY, otherwise the write is ignored. This Field is not banked between Security states.